@@ -32,6 +32,7 @@
 #include <rocprofiler-sdk/fwd.h>
 #include <rocprofiler-sdk/marker/api_id.h>
 #include <rocprofiler-sdk/rocprofiler.h>
+#include <rocprofiler-sdk/cxx/constants.hpp>
 #include <rocprofiler-sdk/cxx/hash.hpp>
 #include <rocprofiler-sdk/cxx/operators.hpp>
 #include <rocprofiler-sdk/cxx/perfetto.hpp>
@@ -491,9 +492,8 @@ write_otf2(const output_config&                                          cfg,
         {
             // Free functions do not track agent information. Below handles case where
             // null rocprof agent id is passed to generate OTF2
-            constexpr auto             null_rocp_agent_id = rocprofiler_agent_id_t{.handle = 0};
-            const rocprofiler_agent_t* _agent             = nullptr;
-            if(agent != null_rocp_agent_id)
+            const rocprofiler_agent_t* _agent = nullptr;
+            if(agent != sdk::null_agent_id)
             {
                 _agent = _get_agent(agent);
             }
@@ -895,9 +895,8 @@ write_otf2(const output_config&                                          cfg,
             auto _hash = get_hash_id(evt.name);
             // Using max numeric limits results in an out-of-bound runtime error for OTF2
             // and perfetto for agent ids. Setting handle to 0 for free functions.
-            constexpr auto null_rocp_agent_id = rocprofiler_agent_id_t{.handle = 0};
-            auto           handle             = agent.handle;
-            if(agent == null_rocp_agent_id) handle = 0;
+            auto handle = agent.handle;
+            if(agent == sdk::null_agent_id) handle = 0;
 
             add_write_string(_hash, evt.name);
             OTF2_CHECK(OTF2_GlobalDefWriter_WriteLocation(global_def_writer,
