@@ -28,6 +28,7 @@
 #include "lib/rocprofiler-sdk/counters/controller.hpp"
 #include "lib/rocprofiler-sdk/counters/core.hpp"
 #include "lib/rocprofiler-sdk/counters/id_decode.hpp"
+#include "lib/rocprofiler-sdk/counters/ioctl.hpp"
 #include "lib/rocprofiler-sdk/hsa/agent_cache.hpp"
 #include "lib/rocprofiler-sdk/hsa/details/fmt.hpp"
 #include "lib/rocprofiler-sdk/hsa/hsa.hpp"
@@ -438,6 +439,15 @@ start_agent_ctx(const context::context* ctx)
             break;
         }
 
+        // Lock the device for profiling (non-fatal if it fails)
+        if(counters::counter_collection_has_device_lock())
+        {
+            counters::counter_collection_device_lock(agent->get_rocp_agent(), true);
+        }
+
+        // Disable PTL (non-fatal if it fails)
+        counters::counter_collection_ptl_disable(agent->get_rocp_agent());
+
         callback_data.set_profile = false;
 
         // Ask the tool what profile we should use for this agent
@@ -571,6 +581,15 @@ stop_agent_ctx(const context::context* ctx)
                                                           1,
                                                           UINT64_MAX,
                                                           HSA_WAIT_STATE_ACTIVE);
+
+        // Re-enable PTL (non-fatal if it fails)
+        counters::counter_collection_ptl_enable(agent->get_rocp_agent());
+
+        // Unlock the device (non-fatal if it fails)
+        if(counters::counter_collection_has_device_lock())
+        {
+            counters::counter_collection_device_unlock(agent->get_rocp_agent());
+        }
     }
 
     agent_ctx.status.exchange(rocprofiler::context::device_counting_service::state::DISABLED);
