@@ -601,6 +601,20 @@ ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipLibraryGetKernel_fn, 499);
 ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipLibraryGetKernelCount_fn, 500);
 #endif
 
+#if HIP_RUNTIME_API_TABLE_STEP_VERSION >= 16
+ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipStreamCopyAttributes_fn, 501);
+#endif
+
+#if HIP_RUNTIME_API_TABLE_STEP_VERSION >= 17
+ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipLibraryEnumerateKernels_fn, 502);
+ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipKernelGetLibrary_fn, 503);
+ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipKernelGetName_fn, 504);
+#endif
+
+#if HIP_RUNTIME_API_TABLE_STEP_VERSION >= 18
+ROCP_SDK_ENFORCE_ABI(::HipDispatchTable, hipOccupancyAvailableDynamicSMemPerBlock_fn, 505);
+#endif
+
 #if HIP_RUNTIME_API_TABLE_STEP_VERSION == 0
 ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 442)
 #elif HIP_RUNTIME_API_TABLE_STEP_VERSION == 1
@@ -633,6 +647,12 @@ ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 477)
 ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 496)
 #elif HIP_RUNTIME_API_TABLE_STEP_VERSION == 15
 ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 501)
+#elif HIP_RUNTIME_API_TABLE_STEP_VERSION == 16
+ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 502)
+#elif HIP_RUNTIME_API_TABLE_STEP_VERSION == 17
+ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 505)
+#elif HIP_RUNTIME_API_TABLE_STEP_VERSION == 18
+ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 506)
 #else
 INTERNAL_CI_ROCP_SDK_ENFORCE_ABI_VERSIONING(::HipDispatchTable, 0)
 #endif
